Cirro-Privacy Policy

# Cirrocumulus Privacy Policy

## Information gathering

Cirrocumulus receives information related to user's Google profiles, including email addresses and OAuth tokens. This information is gathered as part of the standard Google sign-in process.

## Use of information

Cirrocumulus uses the information gathered above to enable integration with Google-based services that require a Google account, such as Google Cloud Storage Platform. At no time do we disclose any user information to outside sources.

## Contact

If you have any questions about this privacy statement, the practices of this site, or your dealings with this site, you can contact us at cumulus@broadinstitute.org.